#!/bin/sh
#
# This script excludes udp port 123 (ntp) and tcp port 22 (ssh) for the
# following reasons:
#
# 1. ntp is required to sync time for replay attack prevention
# 2. ssh obviously does proper encryption itself
#

IPTABLES=/sbin/iptables

mode=$1
txqueue=$2
rxqueue=$3

work()
{
case $mode in
up)	op=-A
	;;
down)	op=-D
	;;
*)	return
	;;
esac

while [ 1 ]
do
	read dev net comment || return

	$IPTABLES -t mangle $op PREROUTING -i $dev -p udp -s $net \
		--match udp ! --source-port 123 \
		-j NFQUEUE  --queue-num $rxqueue
	$IPTABLES -t mangle $op PREROUTING -i $dev -p tcp -s $net \
		--match tcp ! --source-port 22 \
		-j NFQUEUE  --queue-num $rxqueue
	$IPTABLES -t mangle $op POSTROUTING -o $dev -p udp -d $net \
		--match udp ! --destination-port 123 \
		-j NFQUEUE --queue-num $txqueue
	$IPTABLES -t mangle $op POSTROUTING -o $dev -p tcp -d $net \
		--match tcp ! --destination-port 22 \
		-j NFQUEUE --queue-num $txqueue
done
}

cat /etc/ipcrypt.conf | work
